# FastAPI

### 创建项目：

```shell
bomiot project <project_name>
```

###  项目结构

```
my-project/                    # 项目目录
├── fastapi_app/               # fastapi app
│   └── main.py                # 主文件
...
```

- 然后你就可以直接在main.py中编写你的fastapi应用

---

## 参考链接

- [FastAPI 官方文档](https://fastapi.tiangolo.com/zh/)
- [FastAPI GitHub](https://github.com/fastapi/fastapi)

---

如需更多高级用法（如多环境管理、插件扩展等），建议查阅官方文档或社区资源。